==> rock-master-20.01-tools-smurf_0.20180405.orig.tar.gz: rock-master-20.01-tools-smurf_0.20180405/src/Visual.hpp <==
//
// Copyright (c) 2015, Deutsches Forschungszentrum für Künstliche Intelligenz GmbH.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// * Redistributions of source code must retain the above copyright notice, this
//   list of conditions and the following disclaimer.
//
// * Redistributions in binary form must reproduce the above copyright notice,
//   this list of conditions and the following disclaimer in the documentation
//   and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#ifndef VISUAL_H
#define VISUAL_H
#include <urdf_model/types.h>
#include <urdf_model/link.h>
#include <boost/serialization/access.hpp>
#include <boost/serialization/export.hpp>
namespace smurf
{

    /**A replacement for urdf::Visual that hides the visual offset, because
     * in envire the offset is encoded by the structure of the
     * EnvireGraph*/
    struct Visual
    {
        Visual();
        Visual(const urdf::Visual& urdfVisual);
        urdf::GeometrySharedPtr geometry;
        std::string material_name;
        urdf::MaterialSharedPtr material;
        std::string name;

        int groupId;

        urdf::Pose origin;

        bool operator==(const Visual& other) const;
        bool operator!=(const Visual& other) const;

        std::string getName() const 
        {
            return name;
        }

        /**Grants access to boost serialization */
        friend class boost::serialization::access;

        /**Serializes the members of this class*/
        template <typename Archive>
            void serialize(Archive &ar, const unsigned int version)
            {
                throw std::runtime_error("Smurf::Visual::serialize not implemented");
            }

    };
}

#endif // VISUAL_H

==> rock-master-22.06-tools-smurf_0.20220420.orig.tar.gz: rock-master-22.06-tools-smurf_0.20220420/src/Visual.hpp <==
//
// Copyright (c) 2015, Deutsches Forschungszentrum für Künstliche Intelligenz GmbH.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// * Redistributions of source code must retain the above copyright notice, this
//   list of conditions and the following disclaimer.
//
// * Redistributions in binary form must reproduce the above copyright notice,
//   this list of conditions and the following disclaimer in the documentation
//   and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#ifndef VISUAL_H
#define VISUAL_H
#include <urdf_model/types.h>
#include <urdf_model/link.h>
#include <boost/serialization/access.hpp>
#include <boost/serialization/export.hpp>

#include "Material.hpp"
namespace smurf
{

    /**A replacement for urdf::Visual that hides the visual offset, because
     * in envire the offset is encoded by the structure of the
     * EnvireGraph*/
    struct Visual
    {
        Visual();
        Visual(const urdf::Visual& urdfVisual);

        std::string name;
        urdf::GeometrySharedPtr geometry;
        

        int groupId;

        urdf::Pose origin;

        bool operator==(const Visual& other) const;
        bool operator!=(const Visual& other) const;

        std::string getName() const 
        {
            return name;
        }

        void setMaterial(smurf::Material material);
        smurf::Material getMaterial() const;

        /**Grants access to boost serialization */
        friend class boost::serialization::access;

        /**Serializes the members of this class*/
        template <typename Archive>
            void serialize(Archive &ar, const unsigned int version)
            {
                throw std::runtime_error("Smurf::Visual::serialize not implemented");
            }

        private:
            smurf::Material material;

    };
}

#endif // VISUAL_H
